@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: about.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: about.c 1083 2005-06-05 09:56:01Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -543,6 +543,8 @@ void santaHunta (void) {
 	scoreDisplay scoreDisplay;
 	
 	shot.fired = 0;
+	shot.x = 0;
+	shot.y = 0;
 	
 	scoreDisplay.rounds = 0;
 	
@@ -681,15 +683,15 @@ void UIAbout (void) {
 		mvaddstr (7, xpos, "       \\/  \\/                          \\/              \\/                   \\/");
 		mvprintw (9, COLS/2-(strlen("Version")+strlen(VERSION)+1)/2, "Version %s", VERSION);
 		
-		mvaddstr (12, COLS/2-(strlen(_("Brought to you by:")))/2, _("Brought to you by:"));
-		mvaddstr (14, COLS/2-(strlen(_("Main code")))/2, _("Main code"));
-		mvaddstr (15, COLS/2-6, "Oliver Feiler");
-		mvaddstr (17, COLS/2-(strlen(_("Additional code")))/2, _("Additional code"));
-		mvaddstr (18, COLS/2-4, "Rene Puls");
-		mvaddstr (20, COLS/2-(strlen(_("Translation team")))/2, _("Translation team"));
-		mvaddstr (21, COLS/2-31, "Oliver Feiler, Frank van der Loo, Pascal Varet, Simon Isakovic,");
-		mvaddstr (22, COLS/2-32, "Fernando J. Pereda, Marco Cova, Cheng-Lung Sung, Dmitry Petukhov");
-		mvaddstr (23, COLS/2-7, "Douglas Campos");
+		mvaddstr (11, COLS/2-(strlen(_("Brought to you by:")))/2, _("Brought to you by:"));
+		mvaddstr (13, COLS/2-(strlen(_("Main code")))/2, _("Main code"));
+		mvaddstr (14, COLS/2-6, "Oliver Feiler");
+		mvaddstr (16, COLS/2-(strlen(_("Additional code")))/2, _("Additional code"));
+		mvaddstr (17, COLS/2-4, "Rene Puls");
+		mvaddstr (19, COLS/2-(strlen(_("Translation team")))/2, _("Translation team"));
+		mvaddstr (20, COLS/2-31, "Oliver Feiler, Frank van der Loo, Pascal Varet, Simon Isakovic,");
+		mvaddstr (21, COLS/2-32, "Fernando J. Pereda, Marco Cova, Cheng-Lung Sung, Dmitry Petukhov");
+		mvaddstr (22, COLS/2-26, "Douglas Campos, Ray Iwata, Piotr Ozarowski, Yang Huan");
 
 		refresh();
 		getch();
