@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: dialog.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: dialog.c 1083 2005-06-05 09:56:01Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -422,11 +422,11 @@ void UIHelpScreen (void) {
 	mvprintw (centery+1, centerx-offset, "%c:", keybindings.filter);
 	mvprintw (centery+2, centerx-offset, "%c:", keybindings.filtercurrent);
 	mvprintw (centery+3, centerx-offset, "%c:", keybindings.nofilter);
-	mvprintw (centery+4, centerx-offset, "%c:", keybindings.andxor);
-	mvprintw (centery+5, centerx-offset, "%c:", keybindings.newheadlines);
-	mvprintw (centery+6, centerx-offset, "%c:", keybindings.perfeedfilter);
-	mvaddstr (centery+7, centerx-offset, _("tab:"));
-	mvprintw (centery+8, centerx-offset, "%c:", keybindings.about);
+	mvprintw (centery+4, centerx-offset, "%c:", keybindings.newheadlines);
+	mvprintw (centery+5, centerx-offset, "%c:", keybindings.perfeedfilter);
+	mvaddstr (centery+6, centerx-offset, _("tab:"));
+	mvprintw (centery+7, centerx-offset, "%c:", keybindings.about);
+	mvprintw (centery+8, centerx-offset, "%c:", 'E');
 	mvprintw (centery+9, centerx-offset, "%c:", keybindings.quit);
 	/* Descriptions */
 	mvaddstr (centery-9, centerx-offsetstr, _("Add RSS feed..."));
@@ -442,11 +442,11 @@ void UIHelpScreen (void) {
 	mvaddstr (centery+1, centerx-offsetstr, _("Apply filter..."));
 	mvaddstr (centery+2, centerx-offsetstr, _("Only current category"));
 	mvaddstr (centery+3, centerx-offsetstr, _("Remove filter"));
-	mvaddstr (centery+4, centerx-offsetstr, _("Toggle AND/OR filtering"));
-	mvaddstr (centery+5, centerx-offsetstr, _("Show new headlines"));
-	mvaddstr (centery+6, centerx-offsetstr, _("Add conversion filter..."));
-	mvaddstr (centery+7, centerx-offsetstr, _("Type Ahead Find"));
-	mvaddstr (centery+8, centerx-offsetstr, _("About"));
+	mvaddstr (centery+4, centerx-offsetstr, _("Show new headlines"));
+	mvaddstr (centery+5, centerx-offsetstr, _("Add conversion filter..."));
+	mvaddstr (centery+6, centerx-offsetstr, _("Type Ahead Find"));
+	mvaddstr (centery+7, centerx-offsetstr, _("About"));
+	mvaddstr (centery+8, centerx-offsetstr, _("Show error log..."));
 	mvaddstr (centery+9, centerx-offsetstr, _("Quit program"));
 	attroff (WA_REVERSE);
 
@@ -512,17 +512,15 @@ void UIDisplayItemHelp (void) {
 	centerx = COLS / 2;
 	centery = LINES / 2;
 	
-	UISupportDrawBox ((COLS/2)-18, (LINES/2)-3, (COLS/2)+18, (LINES/2)+3);
+	UISupportDrawBox ((COLS/2)-18, (LINES/2)-2, (COLS/2)+18, (LINES/2)+3);
 	
 	attron (WA_REVERSE);
 	/* Keys */
-	mvaddstr (centery-2, centerx-offset, _("cursor:"));
 	mvprintw (centery-1, centerx-offset, "%c, <-:", keybindings.prev);	
 	mvprintw (centery,   centerx-offset, "%c, ->:", keybindings.next);
 	mvprintw (centery+1, centerx-offset, "%c:", keybindings.urljump);
 	mvprintw (centery+2, centerx-offset, _("%c, enter:"), keybindings.prevmenu);
 	/* Descriptions */
-	mvaddstr (centery-2, centerx-offsetstr, _("Scroll text"));
 	mvaddstr (centery-1, centerx-offsetstr, _("Previous item"));	
 	mvaddstr (centery,   centerx-offsetstr, _("Next item"));
 	mvaddstr (centery+1, centerx-offsetstr, _("Open link"));
