@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: interface.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: interface.c 1083 2005-06-05 09:56:01Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -120,7 +120,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 				converted = strdup (newtext);
 			
 			mvaddnstr (2, 1, converted, columns);
-			if (xmlStrlen (converted) > columns)
+			if (xmlStrlen ((xmlChar *)converted) > columns)
 				mvaddstr (2, columns+1, "...");
 				
 			free (converted);
@@ -134,7 +134,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 				converted = strdup (newtext);
 			
 				mvaddnstr (2, 1, converted, columns);
-				if (xmlStrlen (converted) > columns)
+				if (xmlStrlen ((xmlChar *)converted) > columns)
 					mvaddstr (2, columns+1, "...");
 
 				free (converted);
@@ -168,12 +168,12 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 			if (converted == NULL)
 				converted = strdup (newtext);
 			
-			if (xmlStrlen (converted) > columns) {
+			if (xmlStrlen ((xmlChar *)converted) > columns) {
 				mvaddnstr (4, 1, converted, columns);
-				if (xmlStrlen (converted) > columns)
+				if (xmlStrlen ((xmlChar *)converted) > columns)
 					mvaddstr (4, columns+1, "...");
 			} else
-				mvprintw (4, (COLS/2)-(xmlStrlen(converted)/2), "%s", converted);
+				mvprintw (4, (COLS/2)-(xmlStrlen((xmlChar *)converted)/2), "%s", converted);
 			
 			free (converted);
 			free (newtext);
@@ -210,8 +210,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 						if (textslice != NULL) {
 							textlist = malloc (sizeof(struct scrolltext));
 							
-							textlist->line = malloc (strlen(textslice)+1);
-							strcpy (textlist->line, textslice);
+							textlist->line = strdup(textslice);
 							
 							/* Gen double list with new items at bottom. */
 							textlist->next_ptr = NULL;
@@ -406,6 +405,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 	struct newsitem *tmp_first;
 	struct newsitem *first_scr_ptr;
 	struct newsitem *markasread;
+	int highlightline = LINES-1;
 		
 	/* Set highlighted to first_ptr at the beginning.
 	   Otherwise bad things (tm) will happen. */
@@ -528,7 +528,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 				converted = strdup (newtext);
 						
 			mvaddnstr (2, 1, converted, columns);
-			if (xmlStrlen (converted) > columns)
+			if (xmlStrlen ((xmlChar *)converted) > columns)
 				mvaddstr(2, columns+1, "...");
 			
 			free (converted);
@@ -566,6 +566,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 			}
 
 			if (curitem_ptr == highlighted) {
+				highlightline = ypos;
 				highlightnum = itemnum;
 				attron (WA_REVERSE);
 				for (i = 0; i < COLS; i++)
@@ -586,7 +587,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 					converted = strdup (newtext);
 				
 				mvaddnstr (ypos, 1, converted, columns);
-				if (xmlStrlen (converted) > columns)
+				if (xmlStrlen ((xmlChar *)converted) > columns)
 					mvaddstr (ypos, columns+1, "...");
 
 				free (converted);
@@ -649,6 +650,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 			UIStatus (tmpstr, 0, 0);
 		}
 		
+		move (highlightline, 0);
 		uiinput = getch();
 		
 		if (typeahead) {
@@ -749,13 +751,20 @@ int UIDisplayFeed (struct feed * current_feed) {
 					}
 				}
 			}
-			if (uiinput == keybindings.reload) {
+			if ((uiinput == keybindings.reload) ||
+				(uiinput == keybindings.forcereload)) {
 				if (first_bak != NULL) {
 					UIStatus (_("Please deactivate the category filter before using this function."), 2, 0);
 					continue;
 				}
 				if (current_feed->smartfeed == 1)
 					continue;
+					
+				if (uiinput == keybindings.forcereload) {
+					free (current_feed->lastmodified);
+					current_feed->lastmodified = NULL;
+				}
+				
 				UpdateFeed (current_feed);
 				highlighted = current_feed->items;
 				/* Reset first_scr_ptr if reloading. */
@@ -926,6 +935,11 @@ void UIMainInterface (void) {
 	int addfilteritem;
 	int andxor = 0;					/* Toggle for AND/OR combinations of filters. */
 	int update_smartfeeds = 1;
+	int highlightline = LINES-1;	/* Line with current selected item cursor
+	                                   will be moved to this line to have it in
+	                                   the same line as the highlight. Visually
+	                                   impaired users with screen readers seem
+	                                   to need this. */
 	
 
 	first_scr_ptr = first_ptr;
@@ -1125,6 +1139,7 @@ void UIMainInterface (void) {
 			
 			/* Make highlight if we are the highlighted feed */
 			if (cur_ptr == highlighted) {
+				highlightline = ypos;
 				highlightnum = itemnum;
 				attron (WA_REVERSE);
 				for (i = 0; i < COLS; i++)
@@ -1137,7 +1152,7 @@ void UIMainInterface (void) {
 				columns = COLS-9-strlen(_("new"));
 			
 			mvaddnstr (ypos, 1, cur_ptr->title, columns);
-			if (xmlStrlen(cur_ptr->title) > columns)
+			if (xmlStrlen((xmlChar *)cur_ptr->title) > columns)
 				mvaddstr (ypos, columns+1, "...");
 			
 			if (cur_ptr->problem)
@@ -1175,6 +1190,7 @@ void UIMainInterface (void) {
 			UIStatus (tmp, 0, 0);
 		}
 		
+		move (highlightline, 0);
 		uiinput = getch();
 		
 		if (typeahead) {
@@ -1203,11 +1219,20 @@ void UIMainInterface (void) {
 				
 				MainQuit (NULL, NULL);
 			}
-			if (uiinput == keybindings.reload) {
+			if ((uiinput == keybindings.reload) ||
+				(uiinput == keybindings.forcereload)) {
 				if (filters[0] != NULL) {
 					UIStatus (_("Please deactivate the category filter before using this function."), 2, 0);
 					continue;
 				}
+				
+				if (highlighted) {
+					if (uiinput == keybindings.forcereload) {
+						free (highlighted->lastmodified);
+						highlighted->lastmodified = NULL;
+					}
+				}
+				
 				UpdateFeed (highlighted);
 				
 				forceredraw = 1;
@@ -1268,92 +1293,94 @@ void UIMainInterface (void) {
 				
 				/* If the deleted feed was the last one of a specific category,
 				   remove this category from the global list. */
-				if (UIDeleteFeed(highlighted->title) == 1) {
-					/* Do it! */
-					removed = highlighted;
-					/* Save current highlight position. */
-					cur_ptr = highlighted;
-					
-					/* Remove cachefile from filesystem. */
-					hashme = Hashify(highlighted->feedurl);
-					len = (strlen(getenv("HOME")) + strlen(hashme) + 18);
-					file = malloc (len);
-					snprintf (file, len, "%s/.snownews/cache/%s", getenv("HOME"), hashme);
-					
-					/* Errors from unlink can be ignored. Worst thing that happens is that
-					   we delete a file that doesn't exist. */
-					unlink (file);
-					
-					free (file);
-					free (hashme);
-									
-					/* Unlink pointer from chain. */
-					if (highlighted == first_ptr) {
-						/* first element */
-						if (first_ptr->next_ptr != NULL) {
-							first_ptr = first_ptr->next_ptr;
-							first_scr_ptr = first_ptr;
-							highlighted->next_ptr->prev_ptr = NULL;
-						} else {
-							first_ptr = NULL;
-							first_scr_ptr = NULL;
-						}
-						/* Set new highlighted to first_ptr again. */
-						cur_ptr = first_ptr;
-					} else if (highlighted->next_ptr == NULL) {
-						/* last element */
-						/* Set new highlighted to element before deleted one. */
-						cur_ptr = highlighted->prev_ptr;
-						/* If highlighted was first line move first line upward in pointer chain. */
-						if (highlighted == first_scr_ptr)
-							first_scr_ptr = first_scr_ptr->prev_ptr;
+				if (highlighted) {
+					if (UIDeleteFeed(highlighted->title) == 1) {
+						/* Do it! */
+						removed = highlighted;
+						/* Save current highlight position. */
+						cur_ptr = highlighted;
 						
-						highlighted->prev_ptr->next_ptr = NULL;
-					} else {
-						/* element inside list */		
-						/* Set new highlighted to element after deleted one. */
-						cur_ptr = highlighted->next_ptr;
-						/* If highlighted was last line, move first line downward in pointer chain. */
-						if (highlighted == first_scr_ptr)
-							first_scr_ptr = first_scr_ptr->next_ptr;
+						/* Remove cachefile from filesystem. */
+						hashme = Hashify(highlighted->feedurl);
+						len = (strlen(getenv("HOME")) + strlen(hashme) + 18);
+						file = malloc (len);
+						snprintf (file, len, "%s/.snownews/cache/%s", getenv("HOME"), hashme);
 						
-						highlighted->prev_ptr->next_ptr = highlighted->next_ptr;
-						highlighted->next_ptr->prev_ptr = highlighted->prev_ptr;
-					}
-					/* Put highlight to new highlight position. */
-					highlighted = cur_ptr;
-				
-					/* free (removed) pointer */
-					if (removed->smartfeed == 0) {
-						if (removed->items != NULL) {
-							while (removed->items->next_ptr != NULL) {
-								removed->items = removed->items->next_ptr;
-								free (removed->items->prev_ptr->data->title);
-								free (removed->items->prev_ptr->data->link);
-								free (removed->items->prev_ptr->data->description);
-								free (removed->items->prev_ptr);
+						/* Errors from unlink can be ignored. Worst thing that happens is that
+						   we delete a file that doesn't exist. */
+						unlink (file);
+						
+						free (file);
+						free (hashme);
+										
+						/* Unlink pointer from chain. */
+						if (highlighted == first_ptr) {
+							/* first element */
+							if (first_ptr->next_ptr != NULL) {
+								first_ptr = first_ptr->next_ptr;
+								first_scr_ptr = first_ptr;
+								highlighted->next_ptr->prev_ptr = NULL;
+							} else {
+								first_ptr = NULL;
+								first_scr_ptr = NULL;
 							}
-							free (removed->items->data->title);
-							free (removed->items->data->link);
-							free (removed->items->data->description);
-							free (removed->items);
+							/* Set new highlighted to first_ptr again. */
+							cur_ptr = first_ptr;
+						} else if (highlighted->next_ptr == NULL) {
+							/* last element */
+							/* Set new highlighted to element before deleted one. */
+							cur_ptr = highlighted->prev_ptr;
+							/* If highlighted was first line move first line upward in pointer chain. */
+							if (highlighted == first_scr_ptr)
+								first_scr_ptr = first_scr_ptr->prev_ptr;
+							
+							highlighted->prev_ptr->next_ptr = NULL;
+						} else {
+							/* element inside list */		
+							/* Set new highlighted to element after deleted one. */
+							cur_ptr = highlighted->next_ptr;
+							/* If highlighted was last line, move first line downward in pointer chain. */
+							if (highlighted == first_scr_ptr)
+								first_scr_ptr = first_scr_ptr->next_ptr;
+							
+							highlighted->prev_ptr->next_ptr = highlighted->next_ptr;
+							highlighted->next_ptr->prev_ptr = highlighted->prev_ptr;
+						}
+						/* Put highlight to new highlight position. */
+						highlighted = cur_ptr;
+					
+						/* free (removed) pointer */
+						if (removed->smartfeed == 0) {
+							if (removed->items != NULL) {
+								while (removed->items->next_ptr != NULL) {
+									removed->items = removed->items->next_ptr;
+									free (removed->items->prev_ptr->data->title);
+									free (removed->items->prev_ptr->data->link);
+									free (removed->items->prev_ptr->data->description);
+									free (removed->items->prev_ptr);
+								}
+								free (removed->items->data->title);
+								free (removed->items->data->link);
+								free (removed->items->data->description);
+								free (removed->items);
+							}
+							
+							free (removed->feedurl);
+							free (removed->feed);
+							free (removed->title);
+							free (removed->link);
+							free (removed->description);
+							free (removed->lastmodified);
+							free (removed->override);
+							free (removed->original);
+							free (removed->cookies);
+							free (removed->authinfo);
+							free (removed->servauth);
+							free (removed);
 						}
 						
-						free (removed->feedurl);
-						free (removed->feed);
-						free (removed->title);
-						free (removed->link);
-						free (removed->description);
-						free (removed->lastmodified);
-						free (removed->override);
-						free (removed->original);
-						free (removed->cookies);
-						free (removed->authinfo);
-						free (removed->servauth);
-						free (removed);
+						update_smartfeeds = 1;
 					}
-					
-					update_smartfeeds = 1;
 				}
 			}
 			if ((uiinput == KEY_UP) ||
@@ -1435,15 +1462,17 @@ void UIMainInterface (void) {
 					continue;
 				}
 				/* Move item up. */
-				if (highlighted->prev_ptr != NULL) {
-					SwapPointers (highlighted, highlighted->prev_ptr);
-					highlighted = highlighted->prev_ptr;
-						if (highlightnum-1 < 1) {
-							if (first_scr_ptr->prev_ptr != NULL)
-								first_scr_ptr = first_scr_ptr->prev_ptr;
-						}
+				if (highlighted) {
+					if (highlighted->prev_ptr != NULL) {
+						SwapPointers (highlighted, highlighted->prev_ptr);
+						highlighted = highlighted->prev_ptr;
+							if (highlightnum-1 < 1) {
+								if (first_scr_ptr->prev_ptr != NULL)
+									first_scr_ptr = first_scr_ptr->prev_ptr;
+							}
+					}
+					update_smartfeeds = 1;
 				}
-				update_smartfeeds = 1;
 			}
 			if (uiinput == keybindings.movedown) {
 				/* This function is deactivated when a filter is active. */
@@ -1452,15 +1481,18 @@ void UIMainInterface (void) {
 					continue;
 				}
 				/* Move item down. */
-				if (highlighted->next_ptr != NULL) {
-					SwapPointers (highlighted, highlighted->next_ptr);
-					highlighted = highlighted->next_ptr;
-					if (highlightnum+1 > LINES-4) {
-						if (first_scr_ptr->next_ptr != NULL)
-								first_scr_ptr = first_scr_ptr->next_ptr;
+				
+				if (highlighted) {
+					if (highlighted->next_ptr != NULL) {
+						SwapPointers (highlighted, highlighted->next_ptr);
+						highlighted = highlighted->next_ptr;
+						if (highlightnum+1 > LINES-4) {
+							if (first_scr_ptr->next_ptr != NULL)
+									first_scr_ptr = first_scr_ptr->next_ptr;
+						}
 					}
+					update_smartfeeds = 1;
 				}
-				update_smartfeeds = 1;
 			}
 			if (uiinput == keybindings.dfltbrowser)
 				UIChangeBrowser();
@@ -1482,15 +1514,18 @@ void UIMainInterface (void) {
 					UIStatus (_("Please deactivate the category filter before using this function."), 2, 0);
 					continue;
 				}
-				UIChangeFeedName(highlighted);
-				update_smartfeeds = 1;
+				if (highlighted) {
+					UIChangeFeedName(highlighted);
+					update_smartfeeds = 1;
+				}
 			}
 			if (uiinput == keybindings.perfeedfilter) {
 				if (filters[0] != NULL) {
 					UIStatus (_("Please deactivate the category filter before using this function."), 2, 0);
 					continue;
 				}
-				UIPerFeedFilter (highlighted);
+				if (highlighted)
+					UIPerFeedFilter (highlighted);
 			}
 			if (uiinput == keybindings.sortfeeds) {
 				/* Deactivate sorting function if filter is applied. */
@@ -1498,8 +1533,10 @@ void UIMainInterface (void) {
 					UIStatus (_("Please deactivate the category filter before using this function."), 2, 0);
 					continue;
 				}
-				SnowSort();
-				update_smartfeeds = 1;
+				if (highlighted) {
+					SnowSort();
+					update_smartfeeds = 1;
+				}
 			}
 			if (uiinput == keybindings.categorize) {
 				/* This needs to be worked on before it works while a filter is applied! */
@@ -1507,10 +1544,12 @@ void UIMainInterface (void) {
 					UIStatus (_("Please deactivate the category filter before using this function."), 2, 0);
 					continue;
 				}
-				if (highlighted->smartfeed != 0)
-					continue;
-				
-				CategorizeFeed (highlighted);
+				if (highlighted) {
+					if (highlighted->smartfeed != 0)
+						continue;
+					
+					CategorizeFeed (highlighted);
+				}
 			}
 			if (uiinput == keybindings.filter) {
 				/* GUI to set a filter */
@@ -1588,6 +1627,11 @@ void UIMainInterface (void) {
 			/* Redraw screen on ^L */
 			if (uiinput == 12)
 				forceredraw = 1;
+			
+			if (uiinput == 'E') {
+				displayErrorLog();
+				forceredraw = 1;
+			}
 		}
 		if ((uiinput == '\n') || 
 			((uiinput == keybindings.enter) && (!typeahead))) {
