@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: netio.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: netio.c 1058 2005-04-27 18:04:47Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -275,7 +275,9 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	char *body;					/* XML body. */
 	unsigned int length;
 	FILE *stream;				/* Stream socket. */
+#ifdef USE_UNSUPPORTED_AND_BROKEN_CODE
 	int chunked = 0;			/* Content-Encoding: chunked received? */
+#endif
 	int redirectcount;			/* Number of HTTP redirects followed. */
 	char httpstatus[4];			/* HTTP status sent by server. */
 	char tmp[256];
@@ -389,7 +391,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 		fclose (stream);
 		return NULL;
 	}
-	if (checkValidHTTPHeader(servreply, sizeof(servreply)) != 0) {
+	if (checkValidHTTPHeader((unsigned char *)servreply, sizeof(servreply)) != 0) {
 		cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
 		fclose (stream);
 		return NULL;
@@ -462,7 +464,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 						return NULL;
 					}
 					
-					if (checkValidHTTPHeader(netbuf, sizeof(netbuf)) != 0) {
+					if (checkValidHTTPHeader((unsigned char *)netbuf, sizeof(netbuf)) != 0) {
 						cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
 						fclose (stream);
 						return NULL;
@@ -519,7 +521,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 						/* Change cur_ptr->feedurl on 301. */
 						if (cur_ptr->lasthttpstatus == 301) {
 							/* Check for valid redirection URL */
-							if (checkValidHTTPURL(newlocation) != 0) {
+							if (checkValidHTTPURL((unsigned char *)newlocation) != 0) {
 								cur_ptr->problem = 1;
 								cur_ptr->netio_error = NET_ERR_REDIRECT_ERR;
 								fclose (stream);
@@ -644,7 +646,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 		if ((fgets (netbuf, sizeof(netbuf), stream)) == NULL)
 			break;
 		
-		if (checkValidHTTPHeader(netbuf, sizeof(netbuf)) != 0) {
+		if (checkValidHTTPHeader((unsigned char *)netbuf, sizeof(netbuf)) != 0) {
 			cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
 			fclose (stream);
 			return NULL;
@@ -653,8 +655,18 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 		if (strncasecmp (netbuf, "Transfer-Encoding", 17) == 0) {
 			/* Chunked transfer encoding. HTTP/1.1 extension.
 			   http://www.w3.org/Protocols/rfc2616/rfc2616-sec3.html#sec3.6.1 */
+			/* This is not supported, because the contributed dechunk function
+			   does not work with binary data and fails valgrind tests.
+			   Disabled as of 1.5.7. */
+#ifdef USE_UNSUPPORTED_AND_BROKEN_CODE
 			if (strstr (netbuf, "chunked") != NULL)
 				chunked = 1;
+#else
+			cur_ptr->netio_error = NET_ERR_CHUNKED;
+			cur_ptr->problem = 1;
+			fclose (stream);
+			return NULL;
+#endif
 		}
 		/* Get last modified date. This is only relevant on HTTP 200. */
 		if ((strncasecmp (netbuf, "Last-Modified", 13) == 0) &&
@@ -814,6 +826,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	/* Close connection. */
 	fclose (stream);
 	
+#ifdef USE_UNSUPPORTED_AND_BROKEN_CODE
 	if (chunked) {
 		if (decodechunked(body, &length) == NULL) {
 			free (body);
@@ -821,6 +834,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 			return NULL;
 		}
 	}
+#endif
 	
 	/* If inflate==1 we need to decompress the content.. */
 	if (inflate == 1) {
@@ -853,7 +867,7 @@ char * DownloadFeed (char * url, struct feed * cur_ptr, int suppressoutput) {
 	char *tmpstr;
 	int httpproto = 0;			/* 0: http; 1: https */
 	
-	if (checkValidHTTPURL(url) != 0) {
+	if (checkValidHTTPURL((unsigned char *)url) != 0) {
 		cur_ptr->problem = 1;
 		cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
 		return NULL;
