@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: setup.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: setup.c 1083 2005-06-05 09:56:01Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -54,7 +54,7 @@ char *browser;						/* Browser command. lynx is standard. */
 char *proxyname;					/* Hostname of proxyserver. */
 char *useragent;					/* Snownews User-Agent string. */
 unsigned short proxyport = 0;		/* Port on proxyserver to use. */
-int use_colors = 0;					/* Default to disabled. */
+int use_colors = 1;					/* Default to enabled. */
 
 /* Load browser command from ~./snownews/browser. */
 void SetupBrowser (char * file) {
@@ -67,15 +67,13 @@ void SetupBrowser (char * file) {
 		configfile = fopen (file, "w+");
 		if (configfile == NULL)
 			MainQuit (_("Create initial configfile \"config\""), strerror(errno)); /* Still didn't work? */
-		browser = malloc (strlen("lynx %s")+1);
-		strcpy (browser, "lynx %s");
+		browser = strdup("lynx %s");
 		fputs (browser, configfile);
 		fclose (configfile);
 	} else {
 		/* Careful not to overflow char browser! */
 		fgets (filebuf, sizeof(filebuf), configfile);
-		browser = malloc (strlen(filebuf)+1);
-		strncpy (browser, filebuf, strlen(filebuf)+1);
+		browser = strdup(filebuf);
 		fclose (configfile);
 		/* Die newline, die! */
 		if (browser[strlen(browser)-1] == '\n')
@@ -171,6 +169,7 @@ void SetupKeybindings (char * file) {
 	keybindings.feedinfo = 'i';
 	keybindings.reload = 'r';
 	keybindings.reloadall = 'R';
+	keybindings.forcereload = 'T';
 	keybindings.urljump = 'o';
 	keybindings.urljump2 = 'O';
 	keybindings.changefeedname = 'c';
@@ -237,6 +236,8 @@ void SetupKeybindings (char * file) {
 				keybindings.feedinfo = tmpbuf[0];
 			else if (strcmp (freeme, "reload feed") == 0)
 				keybindings.reload = tmpbuf[0];
+			else if (strcmp (freeme, "force reload feed") == 0)
+				keybindings.forcereload = tmpbuf[0];
 			else if (strcmp (freeme, "reload all feeds") == 0)
 				keybindings.reloadall = tmpbuf[0];
 			else if (strcmp (freeme, "open url") == 0)
@@ -313,6 +314,7 @@ void SetupKeybindings (char * file) {
 	fprintf (configfile, "previous item:%c\n", keybindings.prev);
 	fprintf (configfile, "return to previous menu:%c\n", keybindings.prevmenu);
 	fprintf (configfile, "reload feed:%c\n", keybindings.reload);
+	fprintf (configfile, "force reload feed:%c\n", keybindings.forcereload);
 	fprintf (configfile, "open url:%c\n", keybindings.urljump);
 	fprintf (configfile, "open item url in overview:%c\n", keybindings.urljump2);
 	fprintf (configfile, "page up:%c\n", keybindings.pup);
