@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: ui-support.c 500 2004-12-08 14:02:44Z kiza $
+ * $Id: ui-support.c 1083 2005-06-05 09:56:01Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -54,17 +54,11 @@ void InitCurses (void) {
 
 /* Print text in statusbar. */
 void UIStatus (char * text, int delay, int warning) {
-	int i;
-	
-	attron (WA_REVERSE);
 	if (warning)
 		attron (COLOR_PAIR(10));
+	clearLine (LINES-1, INVERSE);
 	
-	/* Clear statusbar. */
-	for (i = 0; i < COLS; i++) {
-		mvaddch (LINES-1, i, ' ');
-	}
-	
+	attron (WA_REVERSE);
 	mvaddnstr (LINES-1, 1, text, COLS-2);
 	
 	/* attroff is called here. If the calling function had it switched on,
@@ -205,12 +199,10 @@ void UISupportDrawBox (int x1, int y1, int x2, int y2) {
 
 /* Draw main program header. */
 void UISupportDrawHeader (char * headerstring) {
-	int i;
-		
+	clearLine (0, INVERSE);
+	
 	attron (WA_REVERSE);
-	for (i = 0; i < COLS; i++) {
-		mvaddch (0, i, ' ');
-	}
+	
 	mvprintw (0, 1, "* Snownews %s", VERSION);
 	if (headerstring != NULL) {
 		if (strlen(headerstring) > COLS-18)
@@ -269,6 +261,8 @@ void UISupportURLJump (char * url) {
 	/* Switch on the cursor. */
 	curs_set(1);
 
+	endwin();
+	
 	system(tmp);
 
 	InitCurses();
@@ -366,4 +360,49 @@ void DrawProgressBar (int numobjects, int titlestrlen) {
 	attroff(WA_REVERSE);
 }
 
+void displayErrorLog (void) {
+	char errorlog[64];
+	char command[96];
+	char *pager = NULL;
+	char *env;
+	
+	/* Get the user's pager or default to less. */
+	env = getenv("PAGER");
+	if (env)
+		pager = strdup(env);
+	else
+		pager = strdup("less");
+	
+	env = getenv("HOME");
+	snprintf (errorlog, sizeof(errorlog), "%s/.snownews/error.log", env);
+	
+	snprintf (command, sizeof(command), "%s %s", pager, errorlog);
 
+	/* Call as few as possible functions once we've left ncurses. */
+	endwin();
+	system(command);
+	InitCurses();
+	
+	clearLine (LINES-1, INVERSE);
+	attron(WA_REVERSE);
+	mvaddnstr (LINES-1, 1, "Press any key to exit the error log display.", COLS-2);
+	attroff(WA_REVERSE);
+	
+	free (pager);
+	
+	getch();
+}
+
+void clearLine (int line, clear_line how) {
+	int i;
+	
+	if (how == INVERSE)
+		attron(WA_REVERSE);
+	
+	for (i = 0; i < COLS; i++) {
+		mvaddch (line, i, ' ');
+	}
+	
+	if (how == INVERSE)
+		attron(WA_REVERSE);
+}
