@@ -1,5 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
- * $Id: ui-support.h 92 2004-10-06 10:29:54Z kiza $
+ * $Id: ui-support.h 1083 2005-06-05 09:56:01Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -24,6 +24,11 @@
 #ifndef UI_SUPPORT_H
 #define UI_SUPPORT_H
 
+typedef enum {
+	NORMAL,
+	INVERSE
+} clear_line;
+
 void InitCurses (void);
 void UIStatus (char * text, int delay, int warning);
 void SwapPointers (struct feed * one, struct feed * two);
@@ -35,5 +40,7 @@ void SmartFeedsUpdate (void);
 void SmartFeedNewitems (struct feed * smart_feed);
 int SmartFeedExists (const char * smartfeed);
 void DrawProgressBar (int numobjects, int titlestrlen);
+void displayErrorLog (void);
+void clearLine (int line, clear_line how);
 
 #endif
